<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Nuevo evento</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Esta borrando un evento.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>¿Está seguro que desea borrar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar todas las instancias de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Borrar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Borrar solo este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar esta y todas las instancias futuras de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Borrar todos los eventos futuros</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 más</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Nuevo evento</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nuevo evento</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Esta borrando un evento.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>¿Está seguro que desea borrar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar todas las instancias de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Borrar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Borrar solo este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar esta y todas las instancias futuras de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>Mi evento</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Borrar todos los eventos futuros</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Nuevo evento</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Editar evento</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Todas las instancias de un evento repetido debe tener el mismo estado todo el día.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>¿Desea cambiar todas las instancias?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Cambiar todos</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Está cambiando la regla de repetición de este evento. </translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Esta cambiando una repetición de un evento.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>¿Desea cambiar solo la instancia de este evento, o todas las instancias?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Solo este evento</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>¿Desea cambiar solo este acontecimiento del evento, o este y todos los acontecimientos futuros?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Todos los futuros eventos</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>En el momento del evento.</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 minutos antes</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 minutos antes</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 hora antes</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 día antes</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 días antes</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 semana antes</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>El día de inicio (9:00 a.m.)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Todo el día</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Recordarme</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Fines de semana</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Anualmente</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Fin de repetición</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Después</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>Hora(s)</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nuevo evento</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>El tiempo final debe ser mayor que el tiempo inicial</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Todo el día</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Termina</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Recordarme</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Fin de repetición</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Termina</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Trabajo</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Personal</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Esta borrando un evento.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>¿Está seguro que desea borrar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar todas las instancias de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Borrar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Borrar solo este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar esta y todas las instancias futuras de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Borrar todos los eventos futuros</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Todo el día</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Sin resultados</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>TODO EL DIA</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Semana</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Todo el día</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Todo el día</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>No hay eventos</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Calendario de Deepin es una herramienta para consultar fechas, y un conveniente planificador para agendar sus reuniones y eventos.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>W</source>
        <translation>S</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Todo el día</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nuevo evento</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Esta borrando un evento.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>¿Está seguro que desea borrar este evento?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar todas las instancias de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Borrar todo</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Borrar solo este evento</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>¿Desea borrar esta y todas las instancias futuras de este evento, o solo la instancia seleccionada?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Borrar todos los eventos futuros</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nuevo evento</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Hoy</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Hoy</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Borrar evento</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Hoy</translation>
    </message>
</context>
</TS>